codebox - Python tools collection.
-----------------------------------------

Installation
==================

.. code-block:: bash

    pip install codebox


Documentation
=============

https://wils0ns.github.io/codebox/
